%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%% CONFIGURATION PART %%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Parameters used for mirror matrix computations %%%%%%%%%%%%%%%%%%%%%%%%%%
global rmir npt thr
rmir = 0.6;         % mirror radius in meters
npt = 151;          % number of points for numerical integration on a grid npt x npt
thr = 0;            % threshold to kill small matrix elements (safer to stay at 0!)
c = 299792458;

% Modes parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global mm M
mm = list_even_modes(8);    % use only even modes for mismatch
M = length(mm);

% Arm cavity parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

itf.RCi = 1416;  % input mirror ROC
itf.RCe = 1646;  % end mirror ROC
itf.L   = 3000;  % length

itf.ti = sqrt(0.0069);                  % input mirror  amplitude transmission 
itf.ri = sqrt(0.9931);                  % input mirror amplitude reflection
itf.li = 0;                             % input mirror losses

itf.te = sqrt(75e-6);                   % end mirror amplitude transmission
itf.le = 0;                             % end mirror losses
itf.re = sqrt(1 - itf.le - itf.te^2);   % end mirror amplitude reflection

% compute the arm cavity mode for latter computations
cav = cavity_mode(itf.RCi, itf.RCe, itf.L);

% compute finesse
itf.Finesse = pi * sqrt(itf.ri*itf.re) / (1 - itf.ri * itf.re);

% Recycling cavities parameteres %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

itf.tp = sqrt(0.04);                    % power recycling mirror amplitude transmission
itf.lp = 0;                             % power recycling mirror losses
itf.rp = sqrt(1 - itf.lp - itf.tp^2);   % power recycling mirror amplitude reflection

itf.ts = sqrt(0.11);            % signal recycling mirror amplitude transmission
itf.ls = 35e-6;                 % signal recycling mirror losses
itf.rs = sqrt(1 - itf.ls - itf.ts^2);   % signal recycling mirror amplitude reflection

itf.Lprc = 37.3444;             
itf.Lsrc = 35.9613;             
itf.Schnupp = 0.10;              % Schnupp asymmetry

itf.fmod1 = 6020832;     
itf.fmod2 = 54187479;     
itf.m = 0.3;

% Define astigmatic recycling cavities 
% (total power recycling length 37.25718 m)

itf.prec.L1 = 10.413;           % distances between mirrors 
itf.prec.L2 = 10.7;
itf.prec.L3 = 10.6742 + 5.55718;
itf.prec.R2 = -2.0;             % radii of curvature
itf.prec.R3 = 23.0304;
itf.prec.alpha = 1.36;          % incidence angle (degrees)

itf.srec.L1 = 10.413;           % distances between mirrors
itf.srec.L2 = 10.7;
itf.srec.L3 = 9.29 + 5.55718;
itf.srec.R2 = -2.0;             % radii of curvature
itf.srec.R3 = 23.0304;
itf.srec.alpha = 1.36;          % incidence angle (degrees)

% Build recycling mirrors (which incorporates the description of NDRC)
[R,T, itf.RCp, itf.wp] = astigmatic_power_recycling(itf.prec, cav, mm);
itf.Rp = itf.rp * R;
itf.Tp = itf.tp * T;

[R,T, itf.RCs, itf.ws] = astigmatic_signal_recycling(itf.srec, cav, mm);
itf.Rs = itf.rs * R;
itf.Ts = itf.ts * T;

% Gouy phase already considered in model of astigmatic cavities
itf.phig_p = 0;
itf.phig_s = 0;


% Aberrations %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
itf.aRCin = itf.RCi;   % radii of curvature
itf.aRCen = itf.RCe;
itf.aRCiw = itf.RCi;   % radii of curvature
itf.aRCew = itf.RCe;
itf.aRCp = itf.RCp;
itf.aRCs = itf.RCs;

itf.fNI = 100e10;      % focal length of input mirror thermal lenses
itf.fWI = 100e10;

% end of parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Build arm cavities (with aberrations if defined)
itf.ncav = build_cavity(itf.RCi, itf.RCe, itf.L, itf.aRCin, itf.aRCen, itf.ri, itf.re, itf.li, itf.le, itf.fNI, mm);
itf.wcav = build_cavity(itf.RCi, itf.RCe, itf.L, itf.aRCiw, itf.aRCew, itf.ri, itf.re, itf.li, itf.le, itf.fWI, mm);

% Length tunings %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
itf.phi_src = 0.15;   
itf.DARM = 1e-11;
itf.PRCL = 0;
itf.CARM = 0;

% compute all thermal lenses for different powers
tic;
NPT = 300;
pabs = linspace(1e-6, 0.3, NPT);
f = 2700 ./ pabs;
L = lenses(f, itf.ncav.w1, list_even_modes(8), rmir, npt, thr);
el = toc;
disp(['Elapsed time: ' num2str(el) ' s'])     

%  rescale lenses to maintain 00 resonant
for i=1:length(L)
    LL(:,:,i) = squeeze(L(:,:,i)) / exp(1j * angle(L(1,1,i)));
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% DEFINE LENSINGS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% build up the 2d map of lenses

nlens = 70;
LN = zeros(M,M,nlens*nlens);
LW = zeros(M,M,nlens*nlens);
pabs_ni = zeros(nlens*nlens,1);
pabs_wi = zeros(nlens*nlens,1);

for i=1:nlens
    for j=1:nlens
        pabs_ni(nlens*(i-1)+j) = pabs(2*i - 1);
        LN(:,:,nlens*(i-1)+j) = LL(:,:,2*i - 1);
        if mod(i,2)
            pabs_wi(nlens*(i-1)+j) = pabs(2*j - 1);
            LW(:,:,nlens*(i-1)+j) = LL(:,:,2*j - 1);
        else
            pabs_wi(nlens*(i-1)+j) = pabs(2*nlens - 2*j + 1);
            LW(:,:,nlens*(i-1)+j) = LL(:,:,2*nlens - 2*j + 1);
        end
    end 
end

NPT = nlens^2;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% LOCKED %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

tic;
Crc = zeros(M,M,NPT);
Csc = zeros(M,M,NPT);
Cdf = zeros(M,M,NPT);
Cn = zeros(M,M,NPT);
Cw  = zeros(M,M,NPT);

Urc = zeros(M,M,NPT);
Usc = zeros(M,M,NPT);
Udf = zeros(M,M,NPT);
Un  = zeros(M,M,NPT);
Uw  = zeros(M,M,NPT);

Lrc = zeros(M,M,NPT);
Lsc = zeros(M,M,NPT);
Ldf = zeros(M,M,NPT);
Ln  = zeros(M,M,NPT);
Lw  = zeros(M,M,NPT);

U2rc = zeros(M,M,NPT);
U2sc = zeros(M,M,NPT);
U2df = zeros(M,M,NPT);
U2n  = zeros(M,M,NPT);
U2w  = zeros(M,M,NPT);

L2rc = zeros(M,M,NPT);
L2sc = zeros(M,M,NPT);
L2df = zeros(M,M,NPT);
L2n  = zeros(M,M,NPT);
L2w  = zeros(M,M,NPT);

NFR = 100;
fr = logspace(1,4,NFR);

TFp = zeros(NFR,NPT);
TFm = zeros(NFR,NPT);

Z = zeros(2, NPT);
phisr = zeros(1,NPT);
phisr(1) = 0.15;
zdarm = zeros(1,NPT);
zdarm(1) = 1e-11;

itf.phi_src = 0.15;
itf.CARM = 0;
itf.MICH = 0;
itf.PRCL = 0;

% loop over all lenses
h = waitbar(0, 'Dual recycled locked');
for i=1:NPT
    % update ITF input thermal lenses
    itf.ncav.Lens = squeeze(LN(:,:,i));
    itf.wcav.Lens = squeeze(LW(:,:,i));
    
    % FIRST LOCK PRCL AND CARM %%%%%%%%%%%%%%
    
    % use last locking point as a starting point
    if i>1
        Z(:,i) = Z(:,i-1);
    end
    
    % maximize sb in PRC
    Z(1,i) = fminsearch(@(x) -maximize_sb(itf, x, Z(2,i)), Z(1,i));
    % then maximize car in arm
    Z(2,i) = fminsearch(@(x) -maximize_car(itf, Z(1,i), x), Z(2,i));
    
    itf.PRCL = 1e-12 * Z(1,i);
    itf.CARM = 1e-12 * Z(2,i);
    
    % THEN LOCK DARM %%%%%%%%%%%%%%%%%%%%%%%%
    
    % maintain the same TEM00 power at dark port
    if i>1
        zdarm(i) = zdarm(i-1);
    end
    zdarm(i) = fzero(@(x) error_darm(itf, x), zdarm(i));
    itf.DARM = 1e-12 * zdarm(i);    
    
    % THEN LOCK SRCL %%%%%%%%%%%%%%%%%%%%%%%%
    
    % try to lock SRC by maximizing TF at peak frequency
    if i>1
        phisr(i) = phisr(i-1);
    end
        
    phisr(i) = fminsearch(@(x) -maximize_sens(itf,x), phisr(i));
    itf.phi_src = phisr(i);
    
    % compute fields
    [Crc(:,:,i), Csc(:,:,i), Cdf(:,:,i), Cn(:,:,i), Cw(:,:,i)] = dualrecycled_fields(itf, 0);
    [U1rc(:,:,i), U1sc(:,:,i), U1df(:,:,i), U1n(:,:,i), U1w(:,:,i)] = dualrecycled_fields(itf, +itf.fmod1);
    [L1rc(:,:,i), L1sc(:,:,i), L1df(:,:,i), L1n(:,:,i), L1w(:,:,i)] = dualrecycled_fields(itf, -itf.fmod1);
    [U2rc(:,:,i), U2sc(:,:,i), U2df(:,:,i), U2n(:,:,i), U2w(:,:,i)] = dualrecycled_fields(itf, +itf.fmod2);
    [L2rc(:,:,i), L2sc(:,:,i), L2df(:,:,i), L2n(:,:,i), L2w(:,:,i)] = dualrecycled_fields(itf, -itf.fmod2);
    
    dccar(i) = dc(squeeze(Crc(:,1,i)), 1);
    dcusb(i) = dc(squeeze(U1rc(:,1,i)), 1);
    dclsb(i) = dc(squeeze(L1rc(:,1,i)), 1);
 
    % compute DARM TF to dark fringe
    x = darm_signal(itf,fr);
    TFp(:,i) = x(1,:).';
    x = darm_signal(itf,-fr);
    TFm(:,i) = x(1,:).';
    tf(:,i) = Cdf(1,1,i) * conj(TFm(:,i)) + conj(Cdf(1,1,i)) * TFp(:,i);
    
    el = toc;
    eta = floor((el / i) * (NPT - i));
    waitbar(i/NPT, h, ['Dual recycled locked (', num2str(floor(100*i/NPT)), '% ETA = ', num2str(eta), 's)']);
    
    fprintf(2, 'PRCL = %g CARM = %g DARM = %g\n', itf.PRCL, itf.CARM, itf.DARM);
    fprintf(2, '     PRC car = %g ARM car = %g  PRC USB = %g PRC LSB = %g\n', dccar(i), abs(Cn(1,1,i))^2, ...
                dcusb(i), dclsb(i));
    fprintf(2, 'phi_src = %f TF = %g\n\n', phisr(i), abs(TFm(52,1)));        
end
close(h);

% compute total DC fields
df_car = dc(squeeze(Cdf(:,1,:)), 1);
sr_car = dc(squeeze(Csc(:,1,:)), 1);
pr_car = dc(squeeze(Crc(:,1,:)), 1);
n_car = dc(squeeze(Cn(:,1,:)), 1);
w_car = dc(squeeze(Cw(:,1,:)), 1);

pr_usb1 = dc(squeeze(U1rc(:,1,:)), 1);
pr_lsb1= dc(squeeze(L1rc(:,1,:)), 1);
pr_usb2 = dc(squeeze(U2rc(:,1,:)), 1);
pr_lsb2= dc(squeeze(L2rc(:,1,:)), 1);
sr_usb2 = dc(squeeze(U2sc(:,1,:)), 1);
sr_lsb2= dc(squeeze(L2sc(:,1,:)), 1);

pr_usb1_00 = abs(squeeze(U1rc(1,1,:))).^2;
pr_lsb1_00 = abs(squeeze(L1rc(1,1,:))).^2;
pr_usb2_00 = abs(squeeze(U2rc(1,1,:))).^2;
pr_lsb2_00 = abs(squeeze(L2rc(1,1,:))).^2;

sr_usb2_00 = abs(squeeze(U2sc(1,1,:))).^2;
sr_lsb2_00 = abs(squeeze(L2sc(1,1,:))).^2;

df_car_00 = abs(squeeze(Cdf(1,1,:))).^2;

% remap all powers in 2x2 grids
PABS_NI = zeros(nlens, nlens);
PABS_WI = zeros(nlens, nlens);
DF_CAR = zeros(nlens, nlens);
DF_CAR_00 = zeros(nlens, nlens);
SR_CAR = zeros(nlens, nlens);
PR_CAR = zeros(nlens, nlens);
PR_USB1 = zeros(nlens, nlens);
PR_LSB1 = zeros(nlens, nlens);
PR_USB1_00 = zeros(nlens, nlens);
PR_LSB1_00 = zeros(nlens, nlens);
PR_USB2 = zeros(nlens, nlens);
PR_LSB2 = zeros(nlens, nlens);
PR_USB2_00 = zeros(nlens, nlens);
PR_LSB2_00 = zeros(nlens, nlens);
SR_USB2 = zeros(nlens, nlens);
SR_LSB2 = zeros(nlens, nlens);
SR_USB2_00 = zeros(nlens, nlens);
SR_LSB2_00 = zeros(nlens, nlens);
N_CAR = zeros(nlens, nlens);
W_CAR = zeros(nlens, nlens);
ZPRCL  = zeros(nlens, nlens);
ZCARM  = zeros(nlens, nlens);
ZDARM  = zeros(nlens, nlens);
PHISRC = zeros(nlens, nlens);

for i=1:nlens
    for j=1:nlens
        if mod(i,2)
            PABS_NI(i,j) = pabs_ni(nlens*(i-1)+j);
            PABS_WI(i,j) = pabs_wi(nlens*(i-1)+j);
            DF_CAR(i,j) = df_car(nlens*(i-1)+j);
            DF_CAR_00(i,j) = df_car_00(nlens*(i-1)+j);
            SR_CAR(i,j) = sr_car(nlens*(i-1)+j);
            PR_CAR(i,j) = pr_car(nlens*(i-1)+j);
            PR_USB1(i,j) = pr_usb1(nlens*(i-1)+j);
            PR_LSB1(i,j) = pr_lsb1(nlens*(i-1)+j);
            PR_USB2(i,j) = pr_usb2(nlens*(i-1)+j);
            PR_LSB2(i,j) = pr_lsb2(nlens*(i-1)+j);
            PR_USB1_00(i,j) = pr_usb1_00(nlens*(i-1)+j);
            PR_LSB1_00(i,j) = pr_lsb1_00(nlens*(i-1)+j);
            PR_USB2_00(i,j) = pr_usb2_00(nlens*(i-1)+j);
            PR_LSB2_00(i,j) = pr_lsb2_00(nlens*(i-1)+j);
            SR_USB2(i,j) = sr_usb2(nlens*(i-1)+j);
            SR_LSB2(i,j) = sr_lsb2(nlens*(i-1)+j);
            SR_USB2_00(i,j) = sr_usb2_00(nlens*(i-1)+j);
            SR_LSB2_00(i,j) = sr_lsb2_00(nlens*(i-1)+j);
            N_CAR(i,j)  = n_car(nlens*(i-1)+j);
            W_CAR(i,j)  = w_car(nlens*(i-1)+j);
            ZPRCL(i,j)   = Z(1,nlens*(i-1)+j);
            ZCARM(i,j)   = Z(2,nlens*(i-1)+j);
            ZDARM(i,j)   = zdarm(nlens*(i-1)+j);
            PHISRC(i,j)  = phisr(nlens*(i-1)+j);
        else
            PABS_NI(i,nlens - j + 1) = pabs_ni(nlens*(i-1)+j);
            PABS_WI(i,nlens - j + 1) = pabs_wi(nlens*(i-1)+j);
            DF_CAR(i,nlens - j + 1) = df_car(nlens*(i-1)+j);
            DF_CAR_00(i,nlens - j + 1) = df_car_00(nlens*(i-1)+j);
            SR_CAR(i,nlens - j + 1) = sr_car(nlens*(i-1)+j);
            PR_CAR(i,nlens - j + 1) = pr_car(nlens*(i-1)+j);
            PR_USB1(i,nlens - j + 1) = pr_usb1(nlens*(i-1)+j);
            PR_LSB1(i,nlens - j + 1) = pr_lsb1(nlens*(i-1)+j);
            PR_USB2(i,nlens - j + 1) = pr_usb2(nlens*(i-1)+j);
            PR_LSB2(i,nlens - j + 1) = pr_lsb2(nlens*(i-1)+j);
            PR_USB1_00(i,nlens - j + 1) = pr_usb1_00(nlens*(i-1)+j);
            PR_LSB1_00(i,nlens - j + 1) = pr_lsb1_00(nlens*(i-1)+j);
            PR_USB2_00(i,nlens - j + 1) = pr_usb2_00(nlens*(i-1)+j);
            PR_LSB2_00(i,nlens - j + 1) = pr_lsb2_00(nlens*(i-1)+j);
            SR_USB2(i,nlens - j + 1) = sr_usb2(nlens*(i-1)+j);
            SR_LSB2(i,nlens - j + 1) = sr_lsb2(nlens*(i-1)+j);
            SR_USB2_00(i,nlens - j + 1) = sr_usb2_00(nlens*(i-1)+j);
            SR_LSB2_00(i,nlens - j + 1) = sr_lsb2_00(nlens*(i-1)+j);
            N_CAR(i,nlens - j + 1)  = n_car(nlens*(i-1)+j);
            W_CAR(i,nlens - j + 1)  = w_car(nlens*(i-1)+j);
            ZPRCL(i,nlens - j + 1)   = Z(1,nlens*(i-1)+j);
            ZCARM(i,nlens - j + 1)   = Z(2,nlens*(i-1)+j);
            ZDARM(i,nlens - j + 1)   = zdarm(nlens*(i-1)+j);
            PHISRC(i,nlens - j + 1)  = phisr(nlens*(i-1)+j);
        end
    end
end

% remap transfer functions and compute sensitivity
hplanck = 6.626068e-34;
nu = 299792458 / 1.064e-6;
Pin = 125;
shot = sqrt(2*hplanck*nu*abs(squeeze(Cdf(1,1,:))).^2 * Pin);

TF = zeros(NFR, nlens, nlens);
SENS = zeros(NFR, nlens, nlens);

for i=1:nlens
    for j=1:nlens
        if mod(i,2)
            TF(:,i,j) = abs(tf(:,nlens*(i-1)+j));
            SENS(:,i,j) = abs(shot(nlens*(i-1)+j) ./ tf(:,nlens*(i-1)+j)./ 3000);
        else
            TF(:,i,nlens - j + 1) = abs(tf(:,nlens*(i-1)+j));
            SENS(:,i,nlens - j + 1) = abs(shot(nlens*(i-1)+j) ./ tf(:,nlens*(i-1)+j)./ 3000);
        end
    end
end


el = toc;
disp(['Elapsed time: ' num2str(el) ' s'])     


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% PLOTS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% plot powers and similar stuffs

figure('Position', [0,0,1200,1200])                                         % dark fringe total power
h = pcolor(1000*PABS_NI, 1000*PABS_WI, DF_CAR);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, DF_CAR, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Dark fringe power (total) [W]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k');
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % dark fringe TEM00 power
h = pcolor(1000*PABS_NI, 1000*PABS_WI, DF_CAR_00);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
%[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, DF_CAR1_00, 'LineColor', 'k');
%clabel(c,h, 'FontSize', 14);
%set(gca, 'fontsize', 15)
title({'Dark fringe power (TEM00) [W]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % carrier recycling gain
h = pcolor(1000*PABS_NI, 1000*PABS_WI, PR_CAR);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, PR_CAR, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Carrier recycling gain';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % sideband1 recycling gain
h = pcolor(1000*PABS_NI, 1000*PABS_WI, PR_USB1);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, PR_USB1, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Upper sideband (6MHz) recycling gain';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % sideband1 recycling gain TEM00
h = pcolor(1000*PABS_NI, 1000*PABS_WI, PR_USB1_00);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, PR_USB1_00, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Upper sideband (6MHz) recycling gain (TEM 00)';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))



figure('Position', [0,0,1200,1200])                                         % sideband1 recycling gain
h = pcolor(1000*PABS_NI, 1000*PABS_WI, PR_LSB1);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, PR_LSB1, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Lower sideband (6MHz) recycling gain';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % sideband1 recycling gain TEM00
h = pcolor(1000*PABS_NI, 1000*PABS_WI, PR_LSB1_00);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, PR_LSB1_00, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Lower sideband (6MHz) recycling gain (TEM 00)';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))




figure('Position', [0,0,1200,1200])                                         % sideband2 recycling gain
h = pcolor(1000*PABS_NI, 1000*PABS_WI, PR_USB2);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, PR_USB2, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Upper sideband (56MHz) recycling gain';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % sideband2 recycling gain 00
h = pcolor(1000*PABS_NI, 1000*PABS_WI, PR_USB2_00);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, PR_USB2_00, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Upper sideband (56MHz) recycling gain TEM00';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % sideband2 recycling gain
h = pcolor(1000*PABS_NI, 1000*PABS_WI, PR_LSB2);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, PR_LSB2, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Lower sideband (56MHz) recycling gain';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % sideband2 recycling gain 00
h = pcolor(1000*PABS_NI, 1000*PABS_WI, PR_LSB2_00);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, PR_LSB2_00, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Lower sideband (56MHz) recycling gain (TEM00)';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % sideband2 power inside signal recycling
h = pcolor(1000*PABS_NI, 1000*PABS_WI, SR_LSB2);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, SR_LSB2, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Lower sideband (56MHz) power inside SRC';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % sideband2 power inside signal recycling
h = pcolor(1000*PABS_NI, 1000*PABS_WI, SR_USB2);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, SR_USB2, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Upper sideband (56MHz) power inside SRC';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))


figure('Position', [0,0,1200,1200])                                         % sideband2 power inside signal recycling 00
h = pcolor(1000*PABS_NI, 1000*PABS_WI, SR_LSB2_00);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, SR_LSB2_00, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Lower sideband (56MHz) power inside SRC TEM00';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % sideband2 power inside signal recycling 00
h = pcolor(1000*PABS_NI, 1000*PABS_WI, SR_USB2_00);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, SR_USB2_00, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Upper sideband (56MHz) power inside SRC TEM00';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % north arm power
h = pcolor(1000*PABS_NI, 1000*PABS_WI, N_CAR);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, N_CAR, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'North arm power [W]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % west arm power
h = pcolor(1000*PABS_NI, 1000*PABS_WI, W_CAR);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, W_CAR, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'West arm power [W]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % north - west arm power
h = pcolor(1000*PABS_NI, 1000*PABS_WI, N_CAR - W_CAR);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, N_CAR - W_CAR, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, -N_CAR + W_CAR, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'North arm power - West arm power [W]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % north - west arm power relative
h = pcolor(1000*PABS_NI, 1000*PABS_WI, 200 * (N_CAR - W_CAR) ./ (N_CAR + W_CAR));
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, 200 * (N_CAR - W_CAR) ./ (N_CAR + W_CAR), 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, -200 * (N_CAR - W_CAR) ./ (N_CAR + W_CAR), 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Arm power unbalance [%]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % PRCL correction
h = pcolor(1000*PABS_NI, 1000*PABS_WI, ZPRCL);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, ZPRCL, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'PRCL correction [pm]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % CARM correction
h = pcolor(1000*PABS_NI, 1000*PABS_WI, ZCARM);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, -ZCARM, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'CARM correction [pm]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % DARM correction
h = pcolor(1000*PABS_NI, 1000*PABS_WI, -ZDARM);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, -ZDARM, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'DARM correction [pm]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % SRC correction
h = pcolor(1000*PABS_NI, 1000*PABS_WI, PHISRC);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, PHISRC, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'SRC tuning [rad]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

% plot sensitivities

idx = min(find(fr>=10));                                                    % Sensitivity at 10 Hz
figure('Position', [0,0,1200,1200])
h = pcolor(1000*PABS_NI, 1000*PABS_WI, 1e22 * squeeze(SENS(idx,:,:)));
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, 1e22 * squeeze(SENS(idx,:,:)), 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Shot-noise limited sensitivity at 10 Hz x 10^{-22} [Hz^{-1/2}]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k',...
    'TickDir', 'out')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

idx = min(find(fr>=100));                                                    % Sensitivity at 100 Hz
figure('Position', [0,0,1200,1200])
h = pcolor(1000*PABS_NI, 1000*PABS_WI, 1e22 * squeeze(SENS(idx,:,:)));
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, 1e22 * squeeze(SENS(idx,:,:)), 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Shot-noise limited sensitivity at 100 Hz x 10^{-22} [Hz^{-1/2}]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k',...
    'TickDir', 'out');
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

idx = min(find(fr>=1000));                                                    % Sensitivity at 1000 Hz
figure('Position', [0,0,1200,1200])
h = pcolor(1000*PABS_NI, 1000*PABS_WI, 1e22 * squeeze(SENS(idx,:,:)));
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, 1e22 * squeeze(SENS(idx,:,:)), 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Shot-noise limited sensitivity at 1 kHz x 10^{-22} [Hz^{-1/2}]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k',...
    'TickDir', 'out');
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

idx = min(find(fr>=300));                                                    % Sensitivity at 300 Hz
figure('Position', [0,0,1200,1200])
h = pcolor(1000*PABS_NI, 1000*PABS_WI, 1e22 * squeeze(SENS(idx,:,:)));
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, 1e22 * squeeze(SENS(idx,:,:)), 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Shot-noise limited sensitivity at 300 Hz x 10^{-22} [Hz^{-1/2}]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k',...
    'TickDir', 'out');
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

% plot sensitivities relative loss
cc = [0 5 10 15 20 30 40 50 60 70 80 90 100];

idx = min(find(fr>=10));                                                    % Sensitivity at 10 Hz relative
figure('Position', [0,0,1200,1200])
h = pcolor(1000*PABS_NI, 1000*PABS_WI, 100* squeeze(SENS(idx,:,:)) / SENS(idx,1,1) - 100);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, 100* squeeze(SENS(idx,:,:)) / SENS(idx,1,1) - 100, cc, 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Shot-noise limit increase at 10 Hz [%]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k',...
    'TickDir', 'out')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

idx = min(find(fr>=100));                                                    % Sensitivity at 100 Hz relative
figure('Position', [0,0,1200,1200])
h = pcolor(1000*PABS_NI, 1000*PABS_WI, 100* squeeze(SENS(idx,:,:)) / SENS(idx,1,1) - 100);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, 100* squeeze(SENS(idx,:,:)) / SENS(idx,1,1) - 100, cc, 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Shot-noise limit increase at 100 Hz [%]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k',...
    'TickDir', 'out')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

idx = min(find(fr>=1000));                                                    % Sensitivity at 1000 Hz relative
figure('Position', [0,0,1200,1200])
h = pcolor(1000*PABS_NI, 1000*PABS_WI, 100* squeeze(SENS(idx,:,:)) / SENS(idx,1,1) - 100);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, 100* squeeze(SENS(idx,:,:)) / SENS(idx,1,1) - 100, cc, 'k');
clabel(c,h, 'FontSize', 14);
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, -(100* squeeze(SENS(idx,:,:)) / SENS(idx,1,1) - 100), cc, 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Shot-noise limit increase at 1 kHz [%]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k',...
    'TickDir', 'out')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))


idx = min(find(fr>=300));                                                    % Sensitivity at 300 Hz relative
figure('Position', [0,0,1200,1200])
h = pcolor(1000*PABS_NI, 1000*PABS_WI, 100* squeeze(SENS(idx,:,:)) / SENS(idx,1,1) - 100);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, 100* squeeze(SENS(idx,:,:)) / SENS(idx,1,1) - 100, cc, 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Shot-noise limit increase at 300 Hz [%]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k',...
    'TickDir', 'out')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))






% remap in TEM modes

% remap all powers in 2x2 grids
PR_00 = zeros(nlens, nlens);
PR_02 = zeros(nlens, nlens);
PR_04 = zeros(nlens, nlens);
PR_06 = zeros(nlens, nlens);
PR_08 = zeros(nlens, nlens);
PR_20 = zeros(nlens, nlens);
PR_22 = zeros(nlens, nlens);
PR_40 = zeros(nlens, nlens);
PR_60 = zeros(nlens, nlens);
PR_80 = zeros(nlens, nlens);

N_00 = zeros(nlens, nlens);
N_02 = zeros(nlens, nlens);
N_04 = zeros(nlens, nlens);
N_06 = zeros(nlens, nlens);
N_08 = zeros(nlens, nlens);

for i=1:nlens
    for j=1:nlens
        if mod(i,2)
            PR_00(i,j) = abs(Crc(1,1,nlens*(i-1)+j))^2;
            PR_02(i,j) = abs(Crc(2,1,nlens*(i-1)+j))^2;
            PR_04(i,j) = abs(Crc(4,1,nlens*(i-1)+j))^2;
            PR_06(i,j) = abs(Crc(7,1,nlens*(i-1)+j))^2;
            PR_08(i,j) = abs(Crc(11,1,nlens*(i-1)+j))^2;
            PR_20(i,j) = abs(Crc(3,1,nlens*(i-1)+j))^2;
            PR_22(i,j) = abs(Crc(5,1,nlens*(i-1)+j))^2;
            PR_40(i,j) = abs(Crc(6,1,nlens*(i-1)+j))^2;
            PR_60(i,j) = abs(Crc(10,1,nlens*(i-1)+j))^2;
            PR_80(i,j) = abs(Crc(15,1,nlens*(i-1)+j))^2;
            N_00(i,j) = abs(Cn(1,1,nlens*(i-1)+j))^2;
            N_02(i,j) = abs(Cn(2,1,nlens*(i-1)+j))^2;
            N_04(i,j) = abs(Cn(4,1,nlens*(i-1)+j))^2;
            N_06(i,j) = abs(Cn(7,1,nlens*(i-1)+j))^2;
            N_08(i,j) = abs(Cn(11,1,nlens*(i-1)+j))^2;
        else
            PR_00(i,nlens - j + 1) = abs(Crc(1,1,nlens*(i-1)+j))^2;
            PR_02(i,nlens - j + 1) = abs(Crc(2,1,nlens*(i-1)+j))^2;
            PR_04(i,nlens - j + 1) = abs(Crc(4,1,nlens*(i-1)+j))^2;
            PR_06(i,nlens - j + 1) = abs(Crc(7,1,nlens*(i-1)+j))^2;
            PR_08(i,nlens - j + 1) = abs(Crc(11,1,nlens*(i-1)+j))^2;
            PR_20(i,nlens - j + 1) = abs(Crc(3,1,nlens*(i-1)+j))^2;
            PR_22(i,nlens - j + 1) = abs(Crc(5,1,nlens*(i-1)+j))^2;
            PR_40(i,nlens - j + 1) = abs(Crc(6,1,nlens*(i-1)+j))^2;
            PR_60(i,nlens - j + 1) = abs(Crc(10,1,nlens*(i-1)+j))^2;
            PR_80(i,nlens - j + 1) = abs(Crc(15,1,nlens*(i-1)+j))^2;
            N_00(i,nlens - j + 1) = abs(Cn(1,1,nlens*(i-1)+j))^2;
            N_02(i,nlens - j + 1) = abs(Cn(2,1,nlens*(i-1)+j))^2;
            N_04(i,nlens - j + 1) = abs(Cn(4,1,nlens*(i-1)+j))^2;
            N_06(i,nlens - j + 1) = abs(Cn(7,1,nlens*(i-1)+j))^2;
            N_08(i,nlens - j + 1) = abs(Cn(11,1,nlens*(i-1)+j))^2;
        end
    end
end


figure('Position', [0,0,1200,1200])                                         % carrier 04
h = pcolor(1000*PABS_NI, 1000*PABS_WI, PR_04);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, PR_04, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'PRC carrier 04 [W]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % carrier 22
h = pcolor(1000*PABS_NI, 1000*PABS_WI, PR_22);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, PR_22, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'PRC carrier 22 [W]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))


figure('Position', [0,0,1200,1200])                                         % carrier 40
h = pcolor(1000*PABS_NI, 1000*PABS_WI, PR_40);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, PR_40, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'PRC carrier 40 [W]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))




figure('Position', [0,0,1200,1200])                                         % carrier 00
h = pcolor(1000*PABS_NI, 1000*PABS_WI, PR_00);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, PR_00, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'PRC carrier 00 [W]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % carrier 02
h = pcolor(1000*PABS_NI, 1000*PABS_WI, PR_02);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, PR_02, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'PRC carrier 02 [W]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % carrier 04
h = pcolor(1000*PABS_NI, 1000*PABS_WI, PR_04);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, PR_04, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'PRC carrier 04 [W]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % carrier 06
h = pcolor(1000*PABS_NI, 1000*PABS_WI, PR_06);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, PR_06, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'PRC carrier 06 [W]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % carrier 08
h = pcolor(1000*PABS_NI, 1000*PABS_WI, PR_08);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, PR_08, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'PRC carrier 08 [W]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))







figure('Position', [0,0,1200,1200])                                         % carrier 00
h = pcolor(1000*PABS_NI, 1000*PABS_WI, N_00);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, N_00, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'North arm carrier 00 [W]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % carrier 02
h = pcolor(1000*PABS_NI, 1000*PABS_WI, N_02);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, N_02, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'Nrth arm carrier 02 [W]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % carrier 04
h = pcolor(1000*PABS_NI, 1000*PABS_WI, N_04);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, N_04, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'North arm carrier 04 [W]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % carrier 06
h = pcolor(1000*PABS_NI, 1000*PABS_WI, N_06);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, N_06, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'North arm carrier 06';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

figure('Position', [0,0,1200,1200])                                         % carrier 08
h = pcolor(1000*PABS_NI, 1000*PABS_WI, N_08);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, N_08, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'North arm carrier 08 [W]';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))

























% remap all powers in 2x2 grids
SR_00 = zeros(nlens, nlens);
SR_02 = zeros(nlens, nlens);
SR_04 = zeros(nlens, nlens);
SR_06 = zeros(nlens, nlens);
SR_08 = zeros(nlens, nlens);


for i=1:nlens
    for j=1:nlens
        if mod(i,2)
            SR_00(i,j) = abs(U1sc(1,1,nlens*(i-1)+j))^2;
            SR_02(i,j) = abs(U1sc(2,1,nlens*(i-1)+j))^2;
            SR_04(i,j) = abs(U1sc(4,1,nlens*(i-1)+j))^2;
            SR_06(i,j) = abs(U1sc(7,1,nlens*(i-1)+j))^2;
            SR_08(i,j) = abs(U1sc(11,1,nlens*(i-1)+j))^2;
        else
            SR_00(i,nlens - j + 1) = abs(U1sc(1,1,nlens*(i-1)+j))^2;
            SR_02(i,nlens - j + 1) = abs(U1sc(2,1,nlens*(i-1)+j))^2;
            SR_04(i,nlens - j + 1) = abs(U1sc(4,1,nlens*(i-1)+j))^2;
            SR_06(i,nlens - j + 1) = abs(U1sc(7,1,nlens*(i-1)+j))^2;
            SR_08(i,nlens - j + 1) = abs(U1sc(11,1,nlens*(i-1)+j))^2;
        end
    end
end







figure('Position', [0,0,1200,1200])                                         % carrier 00
h = pcolor(1000*PABS_NI, 1000*PABS_WI, SR_00);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, SR_00, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))



figure('Position', [0,0,1200,1200])                                         % carrier 00
h = pcolor(1000*PABS_NI, 1000*PABS_WI, SR_02);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, SR_02, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))



figure('Position', [0,0,1200,1200])                                         % carrier 00
h = pcolor(1000*PABS_NI, 1000*PABS_WI, SR_04);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, SR_04, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))



figure('Position', [0,0,1200,1200])                                         % carrier 00
h = pcolor(1000*PABS_NI, 1000*PABS_WI, SR_06);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, SR_06, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))


figure('Position', [0,0,1200,1200])                                         % carrier 00
h = pcolor(1000*PABS_NI, 1000*PABS_WI, SR_08);
colorbar;
set(h, 'EdgeColor', 'none')
hold on
[c,h] = contour3(1000*PABS_NI, 1000*PABS_WI, SR_08, 'LineColor', 'k');
clabel(c,h, 'FontSize', 14);
set(gca, 'fontsize', 15)
title({'';''}, 'fontsize', 20)
xlabel('NI absorbed power [mW]', 'fontsize', 15)
ylabel('WI absorbed power [mW]', 'fontsize', 15)
pbaspect([1 1 1])
ax1 = gca;
ax2 = axes('Position', get(ax1, 'Position'), 'XAxisLocation','top', ...
    'YAxisLocation','right', 'Color', 'none', 'XColor','k','YColor','k')
set(ax2, 'XLim', get(ax1, 'XLim'));
set(ax2, 'YLim', get(ax1, 'YLim'));
flens = [20e3, 30e3, 40e3, 60e3, 100e3, 200e3];
ftic  = {'200km'; '100km'; '60km'; '40km'; '30km'; '20km'};
plens = 2700./flens;
set(ax2, 'XTick', 1000*plens(end:-1:1))
set(ax2, 'YTick', 1000*plens(end:-1:1))
set(ax2, 'XTickLabel', ftic)
set(ax2, 'YTickLabel', ftic)
pbaspect([1 1 1])
set(ax2, 'Position', get(ax1, 'Position'))
