% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Compute operator for astigmatic power recycling cavity. All astigmatism and
% Gouy phases are coded inside the recycling mirror operator (reflection
% and transmission)
%
% function [R,T] = astigmatic_power_recycling(rec, cav, modes)
%
% rec   = structure for describing recyling cavity
%         rec.L1, rec.L2, rec.L3, rec.R2, rec.R3, rec.alpha
% cav   = structure describing arm cavity
% modes = list of modes to be used
%
% R = recycling mirror operator



function [R, T, RC, w] = astigmatic_power_recycling(rec, cav, modes)
    global  npt thr 
    
    M = length(modes);
    
    % beam parameter at cavity reflection
    q0 = cav.L1 + 1j * cav.z0;
    
    % take into account (diverging) lens due to input mirror substrate
    n = 1.44963;
    MLI = [1, 0; (n-1)/cav.R1 1];
    
    % compute mode at input mirror exit
    q1 = ABCD(MLI, q0);
    
    % propagate gaussian parameter to PRM1 and compute Gouy phase
    % in the non-astigmatic basis
    ML1 = [1 rec.L1; 0 1];
    ML2 = [1 rec.L2; 0 1];
    ML3 = [1 rec.L3; 0 1];
    MR3 = [1 0; -2/rec.R3 1];
    MR2 = [1 0; -2/rec.R2 1];
    
    qprm3in_0  = ABCD(ML3, q1);
    qprm3out_0 = ABCD(MR3, qprm3in_0);
    qprm2in_0  = ABCD(ML2, qprm3out_0);
    qprm2out_0 = ABCD(MR2, qprm2in_0);
    qprm1in_0  = ABCD(ML1, qprm2out_0);
    phig_0 = atan(real(qprm3in_0)/imag(qprm3in_0)) - atan(real(q1)/imag(q1)) ...
         + atan(real(qprm2in_0)/imag(qprm2in_0)) - atan(real(qprm3out_0)/imag(qprm3out_0)) ...
         + atan(real(qprm1in_0)/imag(qprm1in_0)) - atan(real(qprm2out_0)/imag(qprm2out_0));
         
    % propagate gaussian parameter to PRM1 and compute Gouy phases
    % in the astigmatic basis
    a = rec.alpha / 180 * pi;
    
    MR3t = [1 0; -2/(rec.R3*cos(a)) 1];
    MR3s = [1 0; -2*cos(a)/rec.R3   1];
    MR2t = [1 0; -2/(rec.R2*cos(a)) 1];
    MR2s = [1 0; -2*cos(a)/rec.R2   1];
    
    qprm3in_t  = ABCD(ML3, q1);
    qprm3out_t = ABCD(MR3t, qprm3in_t);
    qprm2in_t  = ABCD(ML2, qprm3out_t);
    qprm2out_t = ABCD(MR2t, qprm2in_t);
    qprm1in_t  = ABCD(ML1, qprm2out_t);
    phig_t = atan(real(qprm3in_t)/imag(qprm3in_t)) - atan(real(q1)/imag(q1)) ...
         + atan(real(qprm2in_t)/imag(qprm2in_t)) - atan(real(qprm3out_t)/imag(qprm3out_t)) ...
         + atan(real(qprm1in_t)/imag(qprm1in_t)) - atan(real(qprm2out_t)/imag(qprm2out_t));
         
    qprm3in_s  = ABCD(ML3, q1);
    qprm3out_s = ABCD(MR3s, qprm3in_s);
    qprm2in_s  = ABCD(ML2, qprm3out_s);
    qprm2out_s = ABCD(MR2s, qprm2in_s);
    qprm1in_s  = ABCD(ML1, qprm2out_s);
    phig_s = atan(real(qprm3in_s)/imag(qprm3in_s)) - atan(real(q1)/imag(q1)) ...
         + atan(real(qprm2in_s)/imag(qprm2in_s)) - atan(real(qprm3out_s)/imag(qprm3out_s)) ...
         + atan(real(qprm1in_s)/imag(qprm1in_s)) - atan(real(qprm2out_s)/imag(qprm2out_s));
             
    % build propagator in astigmatic basis
    P1 = diag(1j * exp(1j * (modes(:,1) * phig_s + modes(:,2) * phig_t)));
     
    % describe astigmatic beam in terms of round basis
    M1 = coupling_matrix(qprm1in_s, qprm1in_t, qprm1in_0, qprm1in_0, modes, 5, npt, thr);
     
    % reflection over a perfect spherical mirror for the moment
    Rp = eye(M);
    
    % propagate the round basis at PRM1 to input mirror 
    qprm1out   = -conj(qprm1in_0);
    qprm2in_t  = ABCD(ML1, qprm1out);
    qprm2out_t = ABCD(MR2t, qprm2in_t);
    qprm3in_t  = ABCD(ML2, qprm2out_t);
    qprm3out_t = ABCD(MR3t, qprm3in_t);
    q1_t = ABCD(ML3, qprm3out_t);
    q0_t = ABCD(MLI, q1_t);
    
    phig_tb = atan(real(qprm2in_t)/imag(qprm2in_t)) - atan(real(qprm1out)/imag(qprm1out)) ...
            + atan(real(qprm3in_t)/imag(qprm3in_t)) - atan(real(qprm2out_t)/imag(qprm2out_t)) ...
            + atan(real(q1_t)/imag(q1_t)) - atan(real(qprm3out_t)/imag(qprm3out_t));
    
    qprm1out   = -conj(qprm1in_0);
    qprm2in_s  = ABCD(ML1, qprm1out);
    qprm2out_s = ABCD(MR2s, qprm2in_s);
    qprm3in_s  = ABCD(ML2, qprm2out_s);
    qprm3out_s = ABCD(MR3s, qprm3in_s);
    q1_s = ABCD(ML3, qprm3out_s);
    q0_s = ABCD(MLI, q1_s);
    
    phig_sb = atan(real(qprm2in_s)/imag(qprm2in_s)) - atan(real(qprm1out)/imag(qprm1out)) ...
            + atan(real(qprm3in_s)/imag(qprm3in_s)) - atan(real(qprm2out_s)/imag(qprm2out_s)) ...
            + atan(real(q1_s)/imag(q1_s)) - atan(real(qprm3out_s)/imag(qprm3out_s));
  
    % build propagator in astigmatic basis
    P2 = diag(1j * exp(1j * (modes(:,1) * phig_sb + modes(:,2) * phig_tb)));
    
    % express the astigmatic basis at input mirror in terms of original
    % round basis
    q0_0 = -conj(q0);
    M2 = coupling_matrix(q0_s, q0_t, q0_0, q0_0, modes, 5, npt, thr);
    
    % put all together (reflection as seen from inside ITF)
    R = M2 * P2 * Rp * M1 * P1;
    
    % ensure that 00 mode is still resonant
    R = R ./ exp(1j*angle(R(1,1)));
    
    % put all together (transmission as seen from outside ITF)
    T = M2 * P2;
    
    % compute beam parameters at PR
    RC = 1/real(1/qprm1in_0);
    w  = sqrt( -1.064e-6/(pi*imag(1/qprm1in_0)));
    
    
