% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Compute the spatial dependency of a beam, give mode content
%
% [x,y,b] = beamprofile(modes, a, w, R, r, npt)
%
% modes = list of used modes
% a     = list of mode amplitudes
% w     = beam size 
% R     = beam wavefront curvature
% r     = image radius
% npt   = number of points
%
% x,y   = coordinate meshes
% b     = beam image (complex)

function [x,y,b] = beamprofile(modes, a, w, R, r, npt)
    k = 2*pi / 1.064e-6;

    % build coordinate grids
    x = linspace(-r,r,npt);
    y = linspace(-r,r,npt);
    [x,y] = meshgrid(x,y);
    r2 = x.^2 + y.^2;
    
    % empty beam image
    b = zeros(npt, npt);
    
    % sum up all modes
    M = length(modes);
    for i=1:M
        m = modes(i,1);
        n = modes(i,2);
        b = b + a(i) * ...
                sqrt(2/pi) / sqrt(2^(m+n) * factorial(n) * factorial(m)) .* ...
                polyval(HermitePoly(m), sqrt(2)*x/w) .* ...
                polyval(HermitePoly(n), sqrt(2)*y/w) .* ...
                exp(-r2 .* (1/w^2 + 1j*k/(2*R)));
    end
        
