% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Returns cavity mode informations given the 
% two radii of curvature and the length
%
% function [cav] = cavity_mode(R1, R2, L)
%
%   R1, R2 = radii of curvature
%   L      = cavity length
%
%   Return cav structure with elements
%     w0   = waist size
%     z0   = Rayleight range
%     L1   = distance of waist from input mirror
%     w1   = spot size on input mirror
%     w2   = spot size on end mirror
%     phig = Gouy phase (one way)
%     G    = G factor


function [cav] = cavity_mode(R1, R2, L)
    lambda = 1.064e-6;

    L1 = L * (R2 - L) / (R1 + R2 - 2*L);
    L2 = L * (R1 - L) / (R1 + R2 - 2*L);
    z0 = sqrt((R1 - L)*(R2 - L) * L * (R1 + R2 - L) / (R1 + R2 - 2*L)^2);
    w0 = sqrt(lambda * z0 / pi);

    cav.phig = atan(L1/z0) + atan(L2/z0);
    cav.G = (1 - L/R1) * (1 - L/R2);
    
    cav.w1 = w0 * sqrt(1 + (L1/z0)^2);
    cav.w2 = w0 * sqrt(1 + (L2/z0)^2);
    
    cav.L1 = L1;
    cav.L2 = L2;
    cav.z0 = z0;
    cav.w0 = w0;
    cav.R1 = R1;
    cav.R2 = R2;
    cav.L = L;
