% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Compute the base-change matrix give the two Gaussian beam coefficients
%
% function M = coupling_matrix(q1x, q1y, q2x, q2y, modes, rmir, npt, thr)
%
%   q1x/y = input mode
%   q2x/y = output mode
%   modes = list of modes
%   rmir, npt, thr = numerical integration parameters


function M = coupling_matrix(q1x, q1y, q2x, q2y, modes, r, npt, thr)

lambda = 1.064e-6;
k = 2*pi / 1.064e-6;

% compute beams parameters
RC1x = 1 / (real(1/q1x) + 1e-100);
RC2x = 1 / (real(1/q2x) + 1e-100);
RC1y = 1 / (real(1/q1y) + 1e-100);
RC2y = 1 / (real(1/q2y) + 1e-100);

w1x = 1 / sqrt( imag(-1/q1x) * pi / lambda);
w2x = 1 / sqrt( imag(-1/q2x) * pi / lambda);
w1y = 1 / sqrt( imag(-1/q1y) * pi / lambda);
w2y = 1 / sqrt( imag(-1/q2y) * pi / lambda);

rmir = max([w1x,w2x,w1y,w2y]) * r;

% build integration grid
[x,y] = meshgrid(linspace(-rmir,rmir,npt),linspace(-rmir,rmir,npt));
dxdy = (2*rmir / (npt - 1))^2;
x2 = x.^2;
y2 = y.^2;
msk = (x2+y2) < (rmir*rmir);

% compute gaussian term
g = exp(-0.5j*k*x2/RC1x - 0.5j*k*y2/RC1y - x2/w1x^2 - y2/w1y^2 ...
    +0.5j*k*x2/RC2x + 0.5j*k*y2/RC2y - x2/w2x^2 - y2/w2y^2);

M = overlap_hermite(x, y, w1x, w1y, w2x, w2y, modes, 2 / pi * dxdy * msk .* g, thr); 


