% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Compute the transfer function from DARM motion to dark fringe
%
% function t = darm_signal(itf, f)
%
% itf = structure containing ITF definition
% f   = vector of signal frequencies

function t = darm_signal(itf, f)
    %tic;
    
    N = length(f);
    k = 2*pi / 1.064e-6;
    c = 299792458;
    
    % first compute static fields (assuming 00 mode in input)
    [P_rc, P_sc, P_df, P_n, P_w] = dualrecycled_fields(itf, 0);
    PhiN = P_n(:,1);
    PhiW = P_w(:,1);
    
    % basic matrices
    M = length(itf.ncav.modes);
    U = eye(M);
    modes = itf.ncav.modes;
    
    % loop over each frequency
    t = zeros(M,N);
    for i=1:N
        w = 2*pi*f(i);
        % compute propagators at w frequency
        PRC = diag(sqrt(-1j) * exp(1j * k * itf.PRCL - 1j * w/c * itf.Lprc) ...
            * exp(1j * sum(modes') * itf.phig_p));
        PSC = diag(sqrt(-1j) * exp(1j*itf.phi_src/2 - 1j * w/c * itf.Lsrc) ...
            * exp(1j * sum(modes') * itf.phig_s));
        PLm = sqrt(1j) * exp(1j * k * itf.MICH - 1j * w / c * itf.Schnupp/2);
    
        PLN = itf.ncav.PL * exp(1j*k*(0.5*itf.CARM + 0.5*itf.DARM)) * exp(-1j * w/c * itf.ncav.L);
        PLW = itf.wcav.PL * exp(1j*k*(0.5*itf.CARM - 0.5*itf.DARM)) * exp(-1j * w/c * itf.wcav.L);
   
        % w frequency fields at cavity reflections ( DARM ! )
        psiw_n = -k*itf.ncav.Lens*itf.ncav.Ti*PLN * ...
                inv(U + itf.ncav.Re*PLN*itf.ncav.Ri*PLN) * ...
                itf.ncav.Re * PhiN;
        psiw_w =  k*itf.wcav.Lens*itf.wcav.Ti*PLW * ...
                inv(U + itf.wcav.Re*PLW*itf.wcav.Ri*PLW) * ...
                itf.wcav.Re * PhiW;
        
        % symmetric and anti-symmetric fields
        psiw_a = 1/sqrt(2) * (1j * PLm * psiw_n + inv(PLm) * psiw_w);
        psiw_s = 1/sqrt(2) * (PLm *psiw_n + 1j * inv(PLm) * psiw_w);
        
        % compute Michelson operators
        [MSSw, MAAw, MSAw, MASw] = Michelson(itf, f(i));
           
        % dark fringe field
        PRC_Rp_PRC = PRC*itf.Rp*PRC;
        X = 1j*MSAw*PRC_Rp_PRC / (U - 1j*MSSw*PRC_Rp_PRC);
                
        t(:,i) = itf.Ts*PSC/(U - 1j*MAAw*PSC*itf.Rs*PSC + ...
                  X*MASw*PSC*itf.Rp*PSC) * (psiw_a + X*psiw_s);
    end
    
    %el = toc;
    %disp(['Elapsed time: ' num2str(el) ' s'])
