% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Return the static fields in a dual-recycled interferometer for a unity
% input at frequency f. Reduced (faster) version for computing lock error
% signals.
%
% [psi_rc, psi_df, psi_ref] = dualrecycled_fields_forlock(itf, f)
%
% itf = interferometer structure
% f   = field frequency
%
% psi_rc  = field inside power recycling (at PR level, going away from PR)
% psi_df  = field at dark port
% psi_ref = field at reflection port
%


function [psi_rc, psi_df, psi_ref] = dualrecycled_fields_forlock(itf, f)
    
    k = 2*pi / 1.064e-6;
    c = 299792458;
    w = 2*pi*f;
    
    % compute propagators in recycling cavities
    modes = itf.ncav.modes;
    itf.PRC = diag(sqrt(-1j) * exp(1j * k * itf.PRCL - 1j * w/c * itf.Lprc) ...
        * exp(1j * sum(modes') * itf.phig_p));
    itf.PSC = diag(sqrt(-1j) * exp(1j*itf.phi_src/2 - 1j * w/c * itf.Lsrc) ...
        * exp(1j * sum(modes') * itf.phig_s));
    itf.PLm = sqrt(1j) * exp(1j * k * itf.MICH - 1j * w / c * itf.Schnupp/2);
    
    % compute fields
    N = length(itf.ncav.modes);
    U = eye(N);
    
    % Michelson operators
    [itf.MSS, itf.MAA, itf.MSA, itf.MAS] = Michelson(itf, f);
    
    % main fields
    temp = (U - 1j*itf.PSC*itf.MAA*itf.PSC*itf.Rs) \ itf.PSC*itf.MSA*itf.PRC;
    
    psi_rc = (U - 1j*itf.Rp*itf.PRC*itf.MSS*itf.PRC + ...
                itf.Rp*itf.PRC*itf.MAS*itf.PSC*itf.Rs* ...
                temp) \ itf.Tp;
    psi_sc = temp * psi_rc;
    psi_df = itf.Ts * psi_sc;
     
    psi_ref = (1j * itf.Rp' + 1j * itf.Tp * itf.Rp' * itf.Tp) - 1j * itf.Tp * itf.Rp' * psi_rc;
    
    
    
