% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Return the transmission matrix for a lens using a given mode basis
% 
% M = lens(f, w, modes, rmir, npt, thr)
%
%     f     = lens focal
%     w     = beam size at lens
%     modes = list of all modes to be used in [n,m] format
%     rmir  = mirror radius
%     npt   = number of points for numerical integration
%     thr   = below this values coupling coefficients are set to zero

function M = lens(f, w, modes, rlens, npt, thr)
    k = 2*pi / 1.064e-6;

    % build integration grid
    [x,y] = meshgrid(linspace(-rlens,rlens,npt),linspace(-rlens,rlens,npt));
    dxdy = (2*rlens / (npt - 1))^2;
    
    % build phase map function (using variables
    r2 = x.^2 + y.^2;
    Z = r2 / (4*f);
    
    % build Gaussian weight
    g = exp(-2*r2/w^2);
    
    % build mask for mirror radius
    msk = r2 < (rlens*rlens); 
    
    M = overlap_hermite(x, y, w, w, w, w, modes, 2 / pi * dxdy * msk .* g .* exp(2j*k*Z), thr); 