% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Return the reflection matrix for a mirror with mis-matched
% radius of curvature and a tilt, using given gaussian basis for input
% and output beams. Astigmatism included
%
% M = mirror_reflection_qxy(Rc, theta, qiy, qix, qox, qoy, modes, rmir, npt, thr)
%
%     Rc     = mirror radius of curvature
%     theta  = mirror tilt
%     qix, qox = beam parameters at input and output (x direction)
%     qiy, qoy = beam parameters at input and output (y direction)
%     modes  = list of all modes to be used in [n,m] format
%     rm     = mirror radius in units of spot size
%     npt    = number of points for numerical integration
%     thr    = below this values coupling coefficients are set to zero

function M = mirror_reflection_qxy(Rc, aoi, theta, qix, qiy, qox, qoy, modes, rm, npt, thr)
k = 2*pi / 1.064e-6;

% input and output beam parameters
Rix = 1/real(1/qix);
wix  = sqrt( -1.064e-6/(pi*imag(1/qix)));
Rox = 1/real(1/qox);
wox  = sqrt( -1.064e-6/(pi*imag(1/qox)));

Riy = 1/real(1/qiy);
wiy  = sqrt( -1.064e-6/(pi*imag(1/qiy)));
Roy = 1/real(1/qoy);
woy  = sqrt( -1.064e-6/(pi*imag(1/qoy)));

% use average spot size
rmir = rm * (wix*wox*wiy*woy)^0.25;

% build integration grid
[x,y] = meshgrid(linspace(-rmir,rmir,npt),linspace(-rmir,rmir,npt));
dxdy = (2*rmir / (npt - 1))^2;

% build phase map function
x2 = x.^2;
y2 = y.^2;
r2 = x2 + y2;

RCx = Rc * cos(aoi*pi/180);
RCy = Rc / cos(aoi*pi/180);

% build exponential integrand
%g = exp( -x2 * (1/wix^2 + 1/wox^2) -y2 * (1/wiy^2 + 1/woy^2) - 2j*k*theta*x);
g = exp( -x2 * (1/wix^2 + 1/wox^2 + 0.5j*k/Rix - 0.5j*k/Rox - 1j*k/RCx) ...
    -y2 * (1/wiy^2 + 1/woy^2 + 0.5j*k/Riy - 0.5j*k/Roy - 1j*k/RCy) ...
    - 2j*k*theta*x);

% build mask for mirror radius
msk = r2 < (rmir*rmir);

M = overlap_hermite(x, y, wix, wiy, wox, woy, modes, 2 / pi * dxdy * msk .* g, thr);
