% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Helper function that computes the overlap integral
%
% M = overlap_hermite(x, y, wix, wiy, wox, woy, modes, G, thr)
%
%     x, y = coordinates, either vector or matrix
%     wix, wiy = input waist in x and y direction
%     wox, woy = output waist in x and y direction
%     modes  = list of all modes to be used in [n,m] format
%     G = product of gaussian, mask, complex phase and remaining normalization factors
%     thr = below this values coupling coefficients are set to zero

% Refactored from coupling_matrix and optimized for speed, Bas Swinkels, May 2010

function M = overlap_hermite(x, y, wix, wiy, wox, woy, modes, G, thr)

max_order = max(modes(:));

%cache hermite polynomials
global hermite;
if isempty(hermite) %assume for now that max_order stays constant
    hermite = arrayfun(@HermitePoly, 0:max_order, 'UniformOutput', false);
end

%cache factorials
global fact;
if isempty(fact)
    fact = arrayfun(@factorial, 0:max_order);
end

if min(size(x)) == 1 %x,y vectors
    [x,y] = meshgrid(x,y);
end

%make column vectors
x = x(:);
y = y(:);
G = G(:);

%precompute hermite polynomials
Hix = nan(length(x), max_order+1);
Hiy = nan(length(x), max_order+1);
for order = 0:max_order
    Hix(:,order+1) = 1/sqrt(wix * 2^order * fact(order+1)) * polyval(hermite{order+1}, sqrt(2) / wix * x );
    Hiy(:,order+1) = 1/sqrt(wiy * 2^order * fact(order+1)) * polyval(hermite{order+1}, sqrt(2) / wiy * y );
end

if wox == wix
    Hox = Hix;
else
    Hox = nan(length(x), max_order+1);
    for order = 0:max_order
        Hox(:,order+1) = 1/sqrt(wox * 2^order * fact(order+1)) * polyval(hermite{order+1}, sqrt(2) / wox * x);
    end
end

if woy == wiy
    Hoy = Hiy;
else
    Hoy = nan(length(x), max_order+1);
    for order = 0:max_order
        Hoy(:,order+1) = 1/sqrt(woy * 2^order * fact(order+1)) * polyval(hermite{order+1}, sqrt(2) / woy * y);
    end
end

% compute coupling matrix
N = size(modes,1);
M = zeros(N,N);
for i = 1:N %output mode
    hox = modes(i,1);
    hoy = modes(i,2);
    prod_i = Hox(:,hox+1) .* Hoy(:,hoy+1) .* G; %product independent of j
    for j = 1:N %input mode
        hix = modes(j,1);
        hiy = modes(j,2);
        % integrate
        M(i,j) = sum(Hix(:,hix+1) .* Hiy(:,hiy+1) .* prod_i);
    end
end

% kill small elements
M(abs(M) < thr) = 0;