% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Return the reflection matrix for a mirror with mis-matched
% radius of curvature, using a given mode basis
% 
% M = tilted_mirror_reflection(Rc, theta, R, w, modes, rmir, npt, thr)
%
%     Rc    = mirror radius of curvature
%     theta = tilt angle (radians)
%     R     = beam natural radius of curvature at mirror
%     w     = beam size at mirror
%     modes = list of all modes to be used in [n,m] format
%     rmir  = mirror radius
%     npt   = number of points for numerical integration
%     thr   = below this values coupling coefficients are set to zero

function M = tilted_mirror_reflection(Rc, theta, R, w, modes, rmir, npt, thr)
     k = 2*pi / 1.064e-6;

    % build integration grid
    [x,y] = meshgrid(linspace(-rmir,rmir,npt),linspace(-rmir,rmir,npt));
    dxdy = (2*rmir / (npt - 1))^2;
    
    % build phase map function
    r2 = x.^2 + y.^2;
    Z = r2/2 * (1/Rc - 1/R) - theta * x;
    
    % build Gaussian weight
    g = exp(-2*r2/w^2);
    
    % build mask for mirror radius
    msk = r2 < (rmir*rmir); 
    
    % compute matrix for each mode
    M = overlap_hermite(x, y, w, w, w, w, modes, 2 / pi * dxdy * msk.* g.* exp(2j*k*Z), thr);    
    
    % normalize 00 phase
    M = M / exp(1j * angle(M(1,1)));